@@ -8,6 +8,7 @@ use Dompdf\Dompdf;
 use Dompdf\Options;
 use Icinga\Application\Icinga;
 use Icinga\Exception\ProgrammingError;
+use Icinga\Web\Hook;
 use Icinga\Web\Url;
 
 call_user_func(function () {
@@ -20,7 +21,7 @@ call_user_func(function () {
      * @license http://www.gnu.org/copyleft/lesser.html GNU Lesser General Public License
      */
 
-    $baseDir = __DIR__ . '/../../vendor/dompdf';
+    $baseDir = Icinga::app()->getBaseDir('library/vendor/dompdf');
 
     require_once "$baseDir/lib/html5lib/Parser.php";
     require_once "$baseDir/lib/php-font-lib/src/FontLib/Autoloader.php";
@@ -61,12 +62,29 @@ class Pdf
             'src="' . Icinga::app()->getBootstrapDirectory() . '/img/',
             $html
         );
+
+        $request = $controller->getRequest();
+
+        if (Hook::has('Pdfexport')) {
+            $pdfexport = Hook::first('Pdfexport');
+
+            if ($pdfexport->isSupported()) {
+                $pdfexport->streamPdfFromHtml($html, sprintf(
+                    '%s-%s-%d',
+                    $request->getControllerName(),
+                    $request->getActionName(),
+                    time()
+                ));
+
+                return;
+            }
+        }
+
         $options = new Options();
         $options->set('defaultPaperSize', 'A4');
         $dompdf = new Dompdf($options);
         $dompdf->loadHtml($html);
         $dompdf->render();
-        $request = $controller->getRequest();
         $dompdf->stream(
             sprintf(
                 '%s-%s-%d',
