@@ -139,6 +139,13 @@ class LdapConnection implements Selectable, Inspectable
      */
     protected $root;
 
+    /**
+     * LDAP_OPT_NETWORK_TIMEOUT for the LDAP connection
+     *
+     * @var int
+     */
+    protected $timeout;
+
     /**
      * The properties and capabilities of the LDAP server
      *
@@ -178,7 +185,8 @@ class LdapConnection implements Selectable, Inspectable
         $this->bindDn = $config->bind_dn;
         $this->bindPw = $config->bind_pw;
         $this->rootDn = $config->root_dn;
-        $this->port = $config->get('port', 389);
+        $this->port = (int) $config->get('port', 389);
+        $this->timeout = (int) $config->get('timeout', 5);
 
         $this->encryption = $config->encryption;
         if ($this->encryption !== null) {
@@ -427,10 +435,7 @@ class LdapConnection implements Selectable, Inspectable
     {
         $this->bind();
 
-        if ($query->getUsePagedResults()
-            && version_compare(PHP_VERSION, '5.4.0') >= 0
-            && $this->getCapabilities()->hasPagedResult()
-        ) {
+        if ($query->getUsePagedResults() && $this->getCapabilities()->hasPagedResult()) {
             return $this->runPagedQuery($query, $fields);
         } else {
             return $this->runQuery($query, $fields);
@@ -1156,11 +1161,7 @@ class LdapConnection implements Selectable, Inspectable
             $sequenceOf = '30' . str_pad(dechex($sequenceOfOctets), 2, '0', STR_PAD_LEFT) . $sequenceOf;
         }
 
-        if (version_compare(PHP_VERSION, '5.4.0') >= 0) {
-            return hex2bin($sequenceOf);
-        } else {
-            return pack('H*', $sequenceOf);
-        }
+        return hex2bin($sequenceOf);
     }
 
     /**
@@ -1197,6 +1198,9 @@ class LdapConnection implements Selectable, Inspectable
 
         $ds = ldap_connect($hostname, $this->port);
 
+        // Set a proper timeout for each connection
+        ldap_set_option($ds, LDAP_OPT_NETWORK_TIMEOUT, $this->timeout);
+
         // Usage of ldap_rename, setting LDAP_OPT_REFERRALS to 0 or using STARTTLS requires LDAPv3.
         // If this does not work we're probably not in a PHP 5.3+ environment as it is VERY
         // unlikely that the server complains about it by itself prior to a bind request
