@@ -88,6 +88,13 @@ class NavigationItem implements IteratorAggregate
      */
     protected $label;
 
+    /**
+     * The item's description
+     *
+     * @var string
+     */
+    protected $description;
+
     /**
      * This item's parent
      *
@@ -153,7 +160,6 @@ class NavigationItem implements IteratorAggregate
      */
     public function init()
     {
-
     }
 
     /**
@@ -340,7 +346,7 @@ class NavigationItem implements IteratorAggregate
      */
     public function hasChildren()
     {
-        return !$this->getChildren()->isEmpty();
+        return ! $this->getChildren()->isEmpty();
     }
 
     /**
@@ -482,6 +488,30 @@ class NavigationItem implements IteratorAggregate
         return $this;
     }
 
+    /**
+     * Get the item's description
+     *
+     * @return  string
+     */
+    public function getDescription()
+    {
+        return $this->description;
+    }
+
+    /**
+     * Set the item's description
+     *
+     * @param   string  $description
+     *
+     * @return  $this
+     */
+    public function setDescription($description)
+    {
+        $this->description = $description;
+
+        return $this;
+    }
+
     /**
      * Set this item's url target
      *
@@ -513,7 +543,7 @@ class NavigationItem implements IteratorAggregate
     public function getUrl()
     {
         if ($this->url === null && $this->hasChildren()) {
-            $this->setUrl(Url::fromPath('#'));
+            $this->setUrl(Url::fromPath('navigation/dashboard', array('name' => strtolower($this->getName()))));
         }
 
         return $this->url;
@@ -791,7 +821,7 @@ class NavigationItem implements IteratorAggregate
     public function getRender()
     {
         if ($this->render === null) {
-            return true;
+            return $this->getUrl() !== null;
         }
 
         return $this->render;
