@@ -21,14 +21,14 @@
     };
 
     Tooltip.prototype.onRendered = function(evt) {
-        var self = evt.data.self, icinga = evt.data.icinga, el = evt.target;
+        var _this = evt.data.self, icinga = evt.data.icinga, el = evt.target;
 
         $('[title]', el).each(function () {
             var $el = $(this);
             $el.attr('title', $el.data('title-rich') || $el.attr('title'));
         });
-        $('svg .chart-data', el).tipsy({ gravity: 'se', html: true });
-        $('i[title]', el).tipsy({ gravity: $.fn.tipsy.autoNS, offset: 2 });
+        $('svg .chart-data', el).tipsy({ gravity: 'se', html: true, opacity: 1 });
+        $('i[title]', el).tipsy({ gravity: $.fn.tipsy.autoNS, offset: 2, opacity: 1 });
         $('[title]', el).each(function (i, el) {
            var $el = $(el);
            var delay, gravity;
@@ -48,7 +48,8 @@
            delay = delay === undefined ? 500 : delay;
            $el.tipsy({
                gravity: gravity || $.fn.tipsy.autoNS,
-               delayIn: delay
+               delayIn: delay,
+               opacity: 1
            });
         });
 
@@ -63,7 +64,7 @@
                 return;
             }
             var title = $(this).find('.tipsy-inner').html();
-            var atMouse = document.elementFromPoint(self.mouseX, self.mouseY);
+            var atMouse = document.elementFromPoint(_this.mouseX, _this.mouseY);
             var nearestTip = $(atMouse).closest('[original-title="' + title + '"]')[0];
             if (nearestTip) {
                 var tipsy = $.data(nearestTip, 'tipsy');
